@@ -31,13 +31,13 @@ test_that("Scaleset connection pool works",
     expect_is(inst, "list")
     expect_length(inst, 5)
 
-    expect_message(vm$run_script("ls /tmp", id=names(inst)[1:2]), "Creating background pool")
+    vm$run_script("ls /tmp", id=names(inst)[1:2])
     expect_identical(pool_size(), 2L)
 
     expect_silent(vm$get_vm_private_ip_addresses(names(inst[1:2])))
     expect_silent(vm$get_vm_private_ip_addresses(inst[1:2]))
 
-    expect_message(vm$get_vm_private_ip_addresses(), "Creating background pool")
+    vm$get_vm_private_ip_addresses()
     expect_identical(pool_size(), 5L)
 
     expect_silent(vm$get_vm_private_ip_addresses(inst))
